==> wurld-0.1.tar.gz: wurld-0.1/src/Moveable.h <==
#ifndef MOVEABLE_H
#define MOVEABLE_H

#include <spug/RCPtr.h>
#include "Model.h"
#include "GameObject.h"
#include "RenderableObject.h"

class GameEngine;

/**
 * A renderable object that has a position and an orientation.  There is also
 * an associated model which can be modified.
 *
 * A null value can be used for the model - this effectively makes the object
 * invisible.
 */
class Moveable : public RenderableObject, public GameObject {

   private:
      ModelPtr model;
      Vector position, velocity;
      RotMatrix orientation;

   public:
      Moveable();

      Moveable(ModelPtr model, const Vector &position, 
	       const RotMatrix &orientation
	       );

      virtual void render(Scene &scene);

      /** 
       * Sets the position vector.
       * "position" is the absolute position of the object 
       */
      void setPosition(const Vector &newPosition) {
	 position = newPosition;
      }

      /** 
       * Sets the position vector.
       * "position" is the absolute position of the object 
       */
      const Vector &getPosition() const {
	 return position;
      }

      /**
       * Sets the velocity vector.
       */
      void setVelocity(const Vector &newVelocity) {
         velocity = newVelocity;
      }

      /**
       * Returns the velocity vector.
       */
      const Vector &getVelocity() const {
         return velocity;
      }

      /**
       * Sets the orientation (rotation) of the object.
       */
      void setOrientation(const RotMatrix &newOrientation) {
	 orientation = newOrientation;
      }

      /**
       * Sets the associated model.
       */
      void setModel(const ModelPtr &newModel) {
	 model = newModel;
      }

      // Implements GameObject
      virtual void processRenderFrame(GameEngine &engine, Float elapsed);
};

SPUG_RCPTR(Moveable);

#endif

==> wurld-0.2.tar.gz: wurld-0.2/src/Moveable.h <==
#ifndef MOVEABLE_H
#define MOVEABLE_H

#include <spug/RCPtr.h>
#include "Model.h"
#include "GameObject.h"
#include "RenderableObject.h"

class GameEngine;

/**
 * A renderable object that has a position and an orientation.  There is also
 * an associated model which can be modified.
 *
 * A null value can be used for the model - this effectively makes the object
 * invisible.
 */
class Moveable : public RenderableObject, public GameObject {

   private:
      ModelPtr model;
      Vector position, velocity;
      RotMatrix rotation;

   public:
      Moveable();

      Moveable(ModelPtr model, const Vector &position, 
	       const RotMatrix &rotation
	       );

      virtual void render(Scene &scene);

      /** 
       * Sets the position vector.
       * "position" is the absolute position of the object 
       */
      void setPosition(const Vector &newPosition) {
	 position = newPosition;
      }

      /** 
       * Sets the position vector.
       * "position" is the absolute position of the object 
       */
      const Vector &getPosition() const {
	 return position;
      }

      /**
       * Sets the velocity vector.
       */
      void setVelocity(const Vector &newVelocity) {
         velocity = newVelocity;
      }

      /**
       * Returns the velocity vector.
       */
      const Vector &getVelocity() const {
         return velocity;
      }

      /**
       * Sets the rotation of the object.
       */
      void setRotation(const RotMatrix &newRotation) {
	 rotation = newRotation;
      }

      /**
       * Returns the rotation of the object.
       */
      RotMatrix getRotation() const {
         return rotation;
      }

      /**
       * Sets the associated model.
       */
      void setModel(const ModelPtr &newModel) {
	 model = newModel;
      }

      // Implements GameObject
      virtual void processRenderFrame(GameEngine &engine, Float elapsed);
};

SPUG_RCPTR(Moveable);

#endif
